@@ -9,6 +9,8 @@
 #'@param GADSdat \code{GADSdat} object imported via \code{eatGADS}.
 #'@param varName Name of the variable to be cloned.
 #'@param new_varName Name of the new variable.
+#'@param label_suffix Suffix added to variable label for the newly created variable in the \code{GADSdat}.
+#'@param checkVarName Logical. Should \code{new_varName} be checked by \code{\link{checkVarNames}}?
 #'
 #'@return Returns a \code{GADSdat}.
 #'
@@ -17,19 +19,27 @@
 #' pisa_new <- cloneVariable(pisa, varName = "schtype", new_varName = "schtype_new")
 #'
 #'@export
-cloneVariable <- function(GADSdat, varName, new_varName) {
+cloneVariable <- function(GADSdat, varName, new_varName, label_suffix = "", checkVarName = TRUE) {
   UseMethod("cloneVariable")
 }
 #'@export
-cloneVariable.GADSdat <- function(GADSdat, varName, new_varName) {
+cloneVariable.GADSdat <- function(GADSdat, varName, new_varName, label_suffix = "", checkVarName = TRUE) {
   check_GADSdat(GADSdat)
   check_vars_in_GADSdat(GADSdat, vars = varName)
-  if(new_varName %in% namesGADS(GADSdat)) stop("'",  new_varName, "' is already an existing variable in the 'GADSdat'.")
+  check_logicalArgument(checkVarName, argName = checkVarName)
+  if(new_varName %in% namesGADS(GADSdat)) {
+    stop("'",  new_varName, "' is already an existing variable in the 'GADSdat'.")
+  }
 
   dat_only <- GADSdat$dat
   dat_only[[new_varName]] <- dat_only[[varName]]
 
-  suppressMessages(GADSdat2 <- updateMeta(GADSdat, newDat = dat_only))
+  suppressMessages(GADSdat2 <- updateMeta(GADSdat, newDat = dat_only, checkVarNames = checkVarName))
+  if(checkVarName) {
+    new_varName <- checkVarNames(new_varName)
+  }
   GADSdat3 <- reuseMeta(GADSdat2, varName = new_varName, other_GADSdat = GADSdat, other_varName = varName)
-  GADSdat3
+  GADSdat4 <- append_varLabel(GADSdat3, varName = new_varName, label_suffix = label_suffix)
+
+  GADSdat4
 }
